# Command Line Interface

This section contains the API reference for the command line interface. For more information on how to use the command line interface, see the [Tutorial - CLI](../sections/learn/cli.md).

## Utility functions for the pipeline commands

Here are some utility functions to help working with the pipelines in the console.

::: distilabel.cli.pipeline.utils
